@@ -15,6 +15,6 @@
 
 """Recursively compile files in a directory, and render result."""
 
-VERSION = "0.3.0"
-__AUTHOR__ = "Louis Paternault (spalax+python@gresille.org)"
+VERSION = "0.3.1"
+__AUTHOR__ = "Louis Paternault (spalax@gresille.org)"
 __COPYRIGHT__ = "(C) 2015 Louis Paternault. GNU AGPL 3 or later."
